Documentation
¶
Index ¶
- func VerifyEvidence(evidenceType, content string, cfg *config.Config) (bool, error)
- type CmdExit0Verifier
- type FileExistsVerifier
- type GrepHitVerifier
- type Service
- func (s *Service) AddEvidence(memoryID int64, evidenceType, content string) (*memory.Evidence, error)
- func (s *Service) GetEvidenceForMemory(memoryID int64) ([]*memory.Evidence, error)
- func (s *Service) IsMemoryValidated(mem *memory.Memory) (bool, error)
- func (s *Service) VerifyEvidenceForMemory(memoryID int64) (bool, error)
- type TestPassVerifier
- type Verifier
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CmdExit0Verifier ¶
type CmdExit0Verifier struct{}
CmdExit0Verifier executes a command and checks if it exits with code 0
func (*CmdExit0Verifier) GetType ¶
func (v *CmdExit0Verifier) GetType() string
type FileExistsVerifier ¶
type FileExistsVerifier struct{}
FileExistsVerifier checks if a file exists
func (*FileExistsVerifier) GetType ¶
func (v *FileExistsVerifier) GetType() string
type GrepHitVerifier ¶
type GrepHitVerifier struct{}
GrepHitVerifier checks if a pattern exists in a file
func (*GrepHitVerifier) GetType ¶
func (v *GrepHitVerifier) GetType() string
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service handles evidence operations
func NewService ¶
NewService creates a new evidence service
func (*Service) AddEvidence ¶
func (s *Service) AddEvidence(memoryID int64, evidenceType, content string) (*memory.Evidence, error)
AddEvidence adds evidence for a memory
func (*Service) GetEvidenceForMemory ¶
GetEvidenceForMemory retrieves all evidence for a memory
func (*Service) IsMemoryValidated ¶
IsMemoryValidated checks if a memory is properly validated based on its type and evidence
type TestPassVerifier ¶
type TestPassVerifier struct{}
TestPassVerifier checks if a test passes (placeholder implementation)
func (*TestPassVerifier) GetType ¶
func (v *TestPassVerifier) GetType() string
Click to show internal directories.
Click to hide internal directories.