Documentation
¶
Index ¶
- type Extractor
- func (e *Extractor) ExtractAndQueueForVerification(responseText string, memoryService *memory.Service, ...) error
- func (e *Extractor) ExtractAndStoreFromStreamingResponse(responseText string, memoryService *memory.Service, projectID string) error
- func (e *Extractor) ExtractMemories(text string, projectID string) ([]*memory.Memory, error)
- func (e *Extractor) GetCoVeStats() *cove.Stats
- func (e *Extractor) SetCoVeVerifier(verifier *cove.Verifier)
- func (e *Extractor) ValidateAndStoreMemories(memories []*memory.Memory, memoryService *memory.Service) error
- type WantsFactMetadata
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Extractor ¶
type Extractor struct {
// contains filtered or unexported fields
}
Extractor handles automatic extraction of memories from text
func NewExtractor ¶
func NewExtractor(evidenceService *evidence.Service, controller *execution.Controller) *Extractor
NewExtractor creates a new memory extractor
func (*Extractor) ExtractAndQueueForVerification ¶
func (e *Extractor) ExtractAndQueueForVerification(responseText string, memoryService *memory.Service, evidenceService *evidence.Service, projectID string) error
ExtractAndQueueForVerification extracts memories and queues fact candidates for verification
func (*Extractor) ExtractAndStoreFromStreamingResponse ¶
func (e *Extractor) ExtractAndStoreFromStreamingResponse(responseText string, memoryService *memory.Service, projectID string) error
ExtractAndStoreFromStreamingResponse processes a streaming response and extracts memories
func (*Extractor) ExtractMemories ¶
ExtractMemories extracts potential memories from text
func (*Extractor) GetCoVeStats ¶
GetCoVeStats returns CoVe statistics if available
func (*Extractor) SetCoVeVerifier ¶
SetCoVeVerifier sets the CoVe verifier for candidate filtering
type WantsFactMetadata ¶
type WantsFactMetadata struct {
WantsFact bool `json:"wants_fact"`
Original string `json:"original_text"`
}
WantsFactMetadata is metadata indicating a memory wants to be promoted to fact
Click to show internal directories.
Click to hide internal directories.