version

package
v0.8.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "v0.8.4"

Version is the current version of tinyMem This can be overridden at build time using -ldflags "-X github.com/daverage/tinymem/internal/version.Version=vX.Y.Z"

Functions

func CheckForUpdates

func CheckForUpdates() (string, error)

CheckForUpdates checks GitHub for a newer version of tinyMem

func IsNewer

func IsNewer(current, latest string) bool

IsNewer compares two version strings and returns true if latest is newer than current

Types

type Release

type Release struct {
	TagName string `json:"tag_name"`
	Name    string `json:"name"`
}

Release represents a GitHub release

Jump to