Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
Core CoreModule
Project ProjectModule
Server ServerModule
Memory *memory.Service
Execution *execution.Controller
Enforcement *enforcement.Recorder
Ctx context.Context
Cancel context.CancelFunc
}
App holds the core components of the application with better separation of concerns.
func (*App) ContextWithLogger ¶
ContextWithLogger returns a new context with the application's logger.
func (*App) InitializeRecallServices ¶ added in v0.4.0
func (a *App) InitializeRecallServices() *RecallServices
InitializeRecallServices creates and configures the shared recall-related services This includes evidence service, recall engine (lexical-only), extractor, and CoVe if enabled
type CoreModule ¶
CoreModule holds the core application components
type ProjectModule ¶
ProjectModule holds project-specific information
type RecallServices ¶ added in v0.4.0
type RecallServices struct {
EvidenceService *evidence.Service
RecallEngine recall.Recaller
Extractor *extract.Extractor
CoVeVerifier *cove.Verifier // May be nil if CoVe is disabled
LLMProvider llm.Provider // Provider interface for LLM (local, external, or calling AI)
}
RecallServices holds the shared recall-related services
type ServerModule ¶
type ServerModule struct {
Mode doctor.ServerMode
}
ServerModule holds server-specific information
Click to show internal directories.
Click to hide internal directories.