Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MemoryNotification ¶
type MemoryNotification struct {
RecallCount int
RecallStatus recallStatus
}
MemoryNotification describes the recall/notification state for a proxied request.
type ResponseCapture ¶
ResponseCapture holds response data for extraction
type RollingBuffer ¶
type RollingBuffer struct {
// contains filtered or unexported fields
}
RollingBuffer maintains a bounded buffer that keeps only the most recent bytes
func NewRollingBuffer ¶
func NewRollingBuffer(max int) *RollingBuffer
NewRollingBuffer creates a new rolling buffer with the specified maximum size
func (*RollingBuffer) Bytes ¶
func (r *RollingBuffer) Bytes() []byte
Bytes returns the current contents of the buffer
func (*RollingBuffer) Cap ¶
func (r *RollingBuffer) Cap() int
Cap returns the maximum capacity of the buffer
func (*RollingBuffer) Len ¶
func (r *RollingBuffer) Len() int
Len returns the current length of the buffer
func (*RollingBuffer) String ¶
func (r *RollingBuffer) String() string
String returns the buffer contents as a string
Click to show internal directories.
Click to hide internal directories.